(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory(require('react'), require('prismjs')) :
  typeof define === 'function' && define.amd ? define(['react', 'prismjs'], factory) :
  (global = global || self, global.draftJsPrismDecorator = factory(global.React, global.prismjs));
}(this, (function (React, Prism) { 'use strict';

  function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

  var React__default = /*#__PURE__*/_interopDefaultLegacy(React);
  var Prism__default = /*#__PURE__*/_interopDefaultLegacy(Prism);

  function _unsupportedIterableToArray(o, minLen) {
    if (!o) return;
    if (typeof o === "string") return _arrayLikeToArray(o, minLen);
    var n = Object.prototype.toString.call(o).slice(8, -1);
    if (n === "Object" && o.constructor) n = o.constructor.name;
    if (n === "Map" || n === "Set") return Array.from(o);
    if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
  }

  function _arrayLikeToArray(arr, len) {
    if (len == null || len > arr.length) len = arr.length;

    for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

    return arr2;
  }

  function _createForOfIteratorHelperLoose(o, allowArrayLike) {
    var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"];
    if (it) return (it = it.call(o)).next.bind(it);

    if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") {
      if (it) o = it;
      var i = 0;
      return function () {
        if (i >= o.length) return {
          done: true
        };
        return {
          done: false,
          value: o[i++]
        };
      };
    }

    throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
  }

  var defaultFilter = function defaultFilter(block) {
    return block.getType() === "code-block";
  };

  var defaultGetLanguage = function defaultGetLanguage(block) {
    var language = block.getData().get("language");

    if (typeof language !== "string") {
      throw new Error('block.getData().get("language") is not string.');
    }

    return language;
  };
  /**
   * A function to create a DraftDecorator.
   *
   * usage:
   * ```tsx
   * import { EditorState, CompositeDecorator } from "draft-js";
   * import createPrismDecorator from "draft-js-prism-decorator";
   *
   * const decorators = new CompositeDecorator([createPrismDecorator()]);
   * const editorState = EditorState.createEmpty(decorators);
   * ```
   */


  function createPrismDecorator(_temp) {
    var _ref = _temp === void 0 ? {} : _temp,
        _ref$filter = _ref.filter,
        filter = _ref$filter === void 0 ? defaultFilter : _ref$filter,
        _ref$getLanguage = _ref.getLanguage,
        getLanguage = _ref$getLanguage === void 0 ? defaultGetLanguage : _ref$getLanguage;

    var strategy = createStrategy(filter, getLanguage);
    var component = createTokenComponent(getLanguage);
    return {
      strategy: strategy,
      component: component
    };
  }

  var createStrategy = function createStrategy(filter, getLanguage) {
    return function (contentBlock, callback) {
      if (!filter(contentBlock)) return;
      var blockText = contentBlock.getText();
      var language = getLanguage(contentBlock);
      var tokenList = Prism__default['default'].tokenize(blockText, Prism__default['default'].languages[language]);
      var start = 0;
      var end = 0;

      for (var _iterator = _createForOfIteratorHelperLoose(tokenList), _step; !(_step = _iterator()).done;) {
        var token = _step.value;
        end = end + token.length;

        if (typeof token !== "string") {
          callback(start, end);
        }

        start = end;
      }
    };
  };

  var createTokenComponent = function createTokenComponent(getLanguage) {
    return function (props) {
      var contentBlock = props.contentState.getBlockForKey(props.blockKey);
      var blockText = contentBlock.getText();
      var language = getLanguage(contentBlock);
      var tokenList = Prism__default['default'].tokenize(blockText, Prism__default['default'].languages[language]);
      var start = 0;
      var end = 0;
      var tokenType = "";

      for (var _iterator2 = _createForOfIteratorHelperLoose(tokenList), _step2; !(_step2 = _iterator2()).done;) {
        var token = _step2.value;
        end = end + token.length;

        if (typeof token !== "string") {
          if (start === props.start && end === props.end) {
            tokenType = token.type;
            break;
          }
        }

        start = end;
      }

      return React__default['default'].createElement("span", {
        className: "token " + tokenType,
        "data-offset-key": props.offsetKey
      }, props.children);
    };
  };

  return createPrismDecorator;

})));
//# sourceMappingURL=index.umd.js.map
